Crate aper_stateroom

Crate aper_stateroom 

Structs

AperStateroomService
ClientId
IntentEvent
StateMachineContainerProgram
A StateProgram implementation that can be built from any [StateMachine]. Transitions are stripped of their metadata and passed down to the underlying state machine.

Traits

StateProgram
This trait can be added to a [StateMachine] which takes a [TransitionEvent] as its transition. Only state machines with this trait can be used directly with the aper client/server infrastructure.

Type Aliases

Timestamp